==> green-core-1.76.1.tgz: package/primitives/form-control-footer/form-control-footer.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _renderRemainingCharsBadge, renderRemainingCharsBadge_fn;
import { property } from "lit/decorators.js";
import { when } from "lit/directives/when.js";
import { GdsBadge } from "../../components/badge/badge.component.js";
import { IconTriangleExclamation } from "../../components/icon/icons/triangle-exclamation.component.js";
import { GdsElement } from "../../gds-element.js";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping.js";
import { styles } from "./form-control-footer.styles.js";
let GdsFormControlFooter = class extends GdsElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _renderRemainingCharsBadge);
  }
  render() {
    return html`<div aria-live="polite">
      <div class="error-message">
        <slot name="message"
          >${when(
      this.validationMessage,
      () => html`
              <gds-icon-triangle-exclamation
                solid
              ></gds-icon-triangle-exclamation>
              ${this.validationMessage}
            `
    )}</slot
        >
      </div>
      <div class="char-counter">
        ${when(
      Number.isInteger(this.charCounter),
      () => __privateMethod(this, _renderRemainingCharsBadge, renderRemainingCharsBadge_fn).call(this, this.charCounter)
    )}
      </div>
    </div>`;
  }
};
_renderRemainingCharsBadge = new WeakSet();
renderRemainingCharsBadge_fn = function(remaining) {
  let variant;
  if (remaining < 0) {
    variant = "negative";
  } else if (remaining < 20) {
    variant = "warning";
  } else {
    variant = "positive";
  }
  return html`<gds-badge variant="${variant}">${remaining}</gds-badge>`;
};
GdsFormControlFooter.styles = [styles];
__decorateClass([
  property({ type: Number })
], GdsFormControlFooter.prototype, "charCounter", 2);
__decorateClass([
  property()
], GdsFormControlFooter.prototype, "validationMessage", 2);
GdsFormControlFooter = __decorateClass([
  gdsCustomElement("gds-form-control-footer", {
    dependsOn: [GdsBadge, IconTriangleExclamation]
  })
], GdsFormControlFooter);
export {
  GdsFormControlFooter
};

==> green-core-1.82.0.tgz: package/primitives/form-control-footer/form-control-footer.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _renderRemainingCharsBadge, renderRemainingCharsBadge_fn;
import { property } from "lit/decorators.js";
import { when } from "lit/directives/when.js";
import { GdsBadge } from "../../components/badge/badge.component.js";
import { IconTriangleExclamation } from "../../components/icon/icons/triangle-exclamation.component.js";
import { GdsElement } from "../../gds-element.js";
import { watch } from "../../utils/decorators/watch.js";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping.js";
import { styles } from "./form-control-footer.styles.js";
let GdsFormControlFooter = class extends GdsElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _renderRemainingCharsBadge);
  }
  _handleVisibilityChange() {
    this.classList.toggle(
      "visually-hidden",
      !this.errorMessage && !this.charCounter
    );
  }
  connectedCallback() {
    super.connectedCallback();
    this._handleVisibilityChange();
  }
  render() {
    return html`<div aria-live="polite">
      <div class="error-message">
        <slot name="message"
          >${when(
      this.errorMessage,
      () => html`
              <gds-icon-triangle-exclamation
                solid
              ></gds-icon-triangle-exclamation>
              ${this.errorMessage}
            `
    )}</slot
        >
      </div>
      <div class="char-counter" aria-hidden="true">
        ${when(
      Number.isInteger(this.charCounter),
      () => __privateMethod(this, _renderRemainingCharsBadge, renderRemainingCharsBadge_fn).call(this, this.charCounter)
    )}
      </div>
    </div>`;
  }
};
_renderRemainingCharsBadge = new WeakSet();
renderRemainingCharsBadge_fn = function(remaining) {
  let variant;
  if (remaining < 0) {
    variant = "negative";
  } else if (remaining < 20) {
    variant = "warning";
  } else {
    variant = "positive";
  }
  return html`<gds-badge variant="${variant}">${remaining}</gds-badge>`;
};
GdsFormControlFooter.styles = [styles];
__decorateClass([
  property({ type: Number })
], GdsFormControlFooter.prototype, "charCounter", 2);
__decorateClass([
  property()
], GdsFormControlFooter.prototype, "errorMessage", 2);
__decorateClass([
  watch("charCounter"),
  watch("errorMessage")
], GdsFormControlFooter.prototype, "_handleVisibilityChange", 1);
GdsFormControlFooter = __decorateClass([
  gdsCustomElement("gds-form-control-footer", {
    dependsOn: [GdsBadge, IconTriangleExclamation]
  })
], GdsFormControlFooter);
export {
  GdsFormControlFooter
};
